@@ -35,10 +35,11 @@ class Inclusive(CloudFormationLintRule):
 
         property_sets = cfn.get_object_without_conditions(properties)
         for property_set in property_sets:
-            for prop in property_set['Object']:
+            obj = property_set['Object'].clean()
+            for prop in obj:
                 if prop in inclusions:
                     for incl_property in inclusions[prop]:
-                        if incl_property not in property_set['Object']:
+                        if incl_property not in obj:
                             if property_set['Scenario'] is None:
                                 message = 'Property {0} should exist with {1} for {2}'
                                 matches.append(RuleMatch(
